==> haskell-cryptonite-conduit-0.2.2-173-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptonite-conduit
version: 0.2.2
id: cryptonite-conduit-0.2.2-JjS00Ux4fm9BhNxoaMD4rM
key: cryptonite-conduit-0.2.2-JjS00Ux4fm9BhNxoaMD4rM
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/haskell-crypto/cryptonite-conduit
synopsis: cryptonite conduit
description:
    Conduit bridge for cryptonite
    .
    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.
category: Cryptography, Conduit
abi: 37e5643795d36eb769496602a34279ad
exposed: True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit
import-dirs: /usr/lib/ghc-8.6.5/site-local/cryptonite-conduit-0.2.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/cryptonite-conduit-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cryptonite-conduit-0.2.2
hs-libraries: HScryptonite-conduit-0.2.2-JjS00Ux4fm9BhNxoaMD4rM
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-GP6MsgQ2BS48W03o5Iyugz
    conduit-extra-1.3.1.1-BpNAtWN1v251tAneLnGOdO
    cryptonite-0.26-5pCtI3fv84M4lNt7lObUcf
    exceptions-0.10.2-EJs0RkZsum56ksbfDqbl1F
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    resourcet-1.2.2-DSV6hnFiraKK5yk15oWe4c transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptonite-conduit-0.2.2-175-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptonite-conduit
version: 0.2.2
id: cryptonite-conduit-0.2.2-KLSDPxn4hA6ACsQilXeCsc
key: cryptonite-conduit-0.2.2-KLSDPxn4hA6ACsQilXeCsc
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/haskell-crypto/cryptonite-conduit
synopsis: cryptonite conduit
description:
    Conduit bridge for cryptonite
    .
    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.
category: Cryptography, Conduit
abi: b2eb8ad502941929b096e6ee3e7237a5
exposed: True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit
import-dirs: /usr/lib/ghc-8.6.5/site-local/cryptonite-conduit-0.2.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/cryptonite-conduit-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cryptonite-conduit-0.2.2
hs-libraries: HScryptonite-conduit-0.2.2-KLSDPxn4hA6ACsQilXeCsc
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-7rGn2miUuc0IzsMPA6GM7m
    conduit-extra-1.3.2-LbcIuxRB9Hk5zbzPLCB0vd
    cryptonite-0.26-5pCtI3fv84M4lNt7lObUcf
    exceptions-0.10.2-EJs0RkZsum56ksbfDqbl1F
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    resourcet-1.2.2-DSV6hnFiraKK5yk15oWe4c transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
